@@ -6,7 +6,8 @@ from googledir.items import GoogledirItem
 
 class GoogleDirectorySpider(CrawlSpider):
 
-    domain_name = 'directory.google.com'
+    name = 'directory.google.com'
+    allowed_domains = ['directory.google.com']
     start_urls = ['http://directory.google.com/']
 
     rules = (
@@ -37,5 +38,3 @@ class GoogleDirectorySpider(CrawlSpider):
 
             # Here we populate the item and yield it
             yield l.load_item()
-
-SPIDER = GoogleDirectorySpider()
